@@ -9,15 +9,22 @@ use warnings;
 use strict;
 use Carp;
 use Path::Tiny;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
-sub get_ignored_files
+sub read_gitignore
 {
     my ($obj, $gitignore_file) = @_;
+    if (! -f $gitignore_file) {
+	carp ".gitignore file $gitignore_file doesn't exist";
+	return undef;
+    }
     my $file = path ($gitignore_file);
     $obj->{file} = $file;
     my @lines = $file->lines ();
     my %ignored;
+    if ($obj->{excludesfile}) {
+	push @lines, @{$obj->{excludesfile}};
+    }
     for my $line (@lines) {
 	if ($line =~ /^\s*#/) {
 	    next;
@@ -27,19 +34,39 @@ sub get_ignored_files
 	    $ignored{$pignored_file} = 1;
 	}
     }
-    $obj->{ignored} = \%ignored;
+    for my $k (keys %ignored) {
+	$obj->{ignored}{$k} = 1;
+    }
+}
+
+sub excludesfile
+{
+    my ($obj, $excludesfile) = @_;
+    if (! -f $excludesfile) {
+	carp "No such excludesfile: $excludesfile";
+	return;
+    }
+    my $file = path ($excludesfile);
+    $obj->{file} = $file;
+    my @lines = $file->lines ();
+    my @oklines;
+    for (@lines) {
+	if (/^\s*(#|$)/) {
+	    next;
+	}
+	push @oklines, $_;
+    }
+    $obj->{excludesfile} = \@oklines;
 }
 
 sub new
 {
     my ($class, $gitignore_file) = @_;
-    if (! -f $gitignore_file) {
-	carp ".gitignore file $gitignore_file doesn't exist";
-	return undef;
-    }
-    my $obj = {};
+    my $obj = {ignored => {}};
     bless $obj, $class;
-    $obj->get_ignored_files ($gitignore_file);
+    if ($gitignore_file) {
+	$obj->read_gitignore ($gitignore_file);
+    }
     return $obj;
 }
 
